from setuptools import setup, find_packages

setup(
    name="happywish",  # must be unique on PyPI
    version="1.0.0",
    packages=find_packages(),
    include_package_data=True,
    install_requires=["playsound"],
    package_data={"happywish": ["music.mp3"]},
    description="Birthday animation + music player",
    author="Adi",
)
